pub enum VerifyError<HO, CE> {
DuplicateKey(Vec<u8>),
ExtraneousNode,
ExtraneousValue(Vec<u8>),
ExtraneousHashReference(HO),
InvalidChildReference(Vec<u8>),
ValueMismatch(Vec<u8>),
IncompleteProof,
RootMismatch(HO),
DecodeError(CE),
}Expand description
Errors that may occur during proof verification. Most of the errors types simply indicate that the proof is invalid with respect to the statement being verified, and the exact error type can be used for debugging.
Variants
DuplicateKey(Vec<u8>)
The statement being verified contains multiple key-value pairs with the same key. The parameter is the duplicated key.
ExtraneousNode
The proof contains at least one extraneous node.
ExtraneousValue(Vec<u8>)
The proof contains at least one extraneous value which should have been omitted from the proof.
ExtraneousHashReference(HO)
The proof contains at least one extraneous hash reference the should have been omitted.
InvalidChildReference(Vec<u8>)
The proof contains an invalid child reference that exceeds the hash length.
ValueMismatch(Vec<u8>)
The proof indicates that an expected value was not found in the trie.
IncompleteProof
The proof is missing trie nodes required to verify.
RootMismatch(HO)
The root hash computed from the proof is incorrect.
DecodeError(CE)
One of the proof nodes could not be decoded.